<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:dlm="http://www.uportal.org/layout/dlm" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" indent="no"/>
<xsl:param name="baseActionURL">render.userLayoutRootNode.uP</xsl:param>
<xsl:param name="baseIdempotentActionURL">render.userLayoutRootNode.uP</xsl:param>
<xsl:param name="uP_productAndVersion">uPortal X.X.X</xsl:param>
<xsl:param name="skin" select="'divs'"/>
<xsl:variable name="mediaPath">media/org/jasig/portal/layout/DLM-tab-column/nested-tables</xsl:variable>
<xsl:variable name="mediaPathSkin" select="concat($mediaPath,'/',$skin,'/skin')"/>
<xsl:variable name="mediaPathControls" select="concat($mediaPath,'/',$skin,'/controls')"/>
<xsl:variable name="mediaPathIcons" select="concat($mediaPath,'/',$skin,'/icons')"/>
<xsl:variable name="uppercase">ABCDEFGHIJKLMNOPQRSTUVWXYZ ':.</xsl:variable>
<xsl:variable name="lowercase">abcdefghijklmnopqrstuvwxyz-</xsl:variable>

<xsl:template match="layout_fragment">
	<html><head>
	<title><xsl:value-of select="content/channel/@name"/></title>
	<meta http-equiv="content-type" content="text/html; charset=UTF-8" />
	<meta http-equiv="expires" content="Wed, 26 Feb 1997 08:21:57 GMT" />
	<meta http-equiv="pragma" content="no-cache" />
	<link type="image/x-icon" rel="icon" href="favicon.ico" />
	<link type="image/x-icon" rel="shortcut icon" href="favicon.ico" />
	<link type="text/css" rel="stylesheet" href="{$mediaPath}/common/skin/standard.css" media="screen" />
	<link type="text/css" rel="stylesheet" href="{$mediaPathSkin}/layout.css" media="screen" />
	<link type="text/css" rel="stylesheet" href="{$mediaPathSkin}/{$skin}.css" media="screen" />
	<link type="text/css" rel="stylesheet" href="{$mediaPathSkin}/icons.css" media="screen" />
	<link type="text/css" rel="stylesheet" href="{$mediaPath}/optional/skin/print.css" media="print"/>
	<script type="text/javascript" src="{$mediaPath}/common/scripts/standard.js">function fakeFunction() { return false; }</script>
	<script type="text/javascript" src="{$mediaPath}/common/scripts/icon-controls.js">function fakeFunction() { return false; }</script>
	<script type="text/javascript">
		var mediaPath = '<xsl:value-of select="$mediaPathControls"/>' + '/';
	</script>
	</head><body>
	<xsl:attribute name="id">body-<xsl:value-of select="translate(//focusedTab//@name,$uppercase,$lowercase)"/></xsl:attribute>

	<div class="display-100-percent"><div class="display-padded-column">
		<xsl:for-each select="content//channel">
			<xsl:apply-templates select=".">
				<xsl:with-param name="detachedContent" select="'true'"/>
			</xsl:apply-templates>
		</xsl:for-each>
	</div></div>

	</body></html>
</xsl:template>

<xsl:template match="layout">
	<html><head>
	<title>
		<xsl:if test="not(//focused)">
			uPortal - <xsl:value-of select="//tab//@pageTitle"/>
		</xsl:if>
		<xsl:if test="//focused">
			<xsl:value-of select="//content//channel//@name"/>
		</xsl:if>
	</title>
	<link type="image/x-icon" rel="icon" href="favicon.ico" />
	<link type="image/x-icon" rel="shortcut icon" href="favicon.ico" />
	<link type="text/css" rel="stylesheet" href="{$mediaPath}/common/skin/standard.css" media="screen"/>
	<link type="text/css" rel="stylesheet" href="{$mediaPathSkin}/layout.css" media="screen" />
	<link type="text/css" rel="stylesheet" href="{$mediaPathSkin}/{$skin}.css" media="screen" />
	<link type="text/css" rel="stylesheet" href="{$mediaPathSkin}/icons.css" media="screen" />
	<link type="text/css" rel="stylesheet" href="{$mediaPath}/optional/skin/print.css" media="print"/>
	<script type="text/javascript" src="{$mediaPath}/common/scripts/standard.js">function fakeFunction() { return false; }</script>
	<script type="text/javascript" src="{$mediaPath}/common/scripts/icon-controls.js">function fakeFunction() { return false; }</script>
	<script type="text/javascript">
		var mediaPath = '<xsl:value-of select="$mediaPathControls"/>' + '/';
	</script>
	</head><body>
	<xsl:attribute name="id">body-<xsl:value-of select="translate(//tab//@pageTitle,$uppercase,$lowercase)"/></xsl:attribute>

		<a href="#tabNavigation" title="Skip to page navigation" id="skipToNav">Skip to page navigation</a>
		<a href="#tabFooter" title="Skip to page content" id="skipToContent">Skip to page content</a>

		<xsl:apply-templates select="header"/>

		<xsl:if test="not(//focused)">
			<xsl:apply-templates select="navigation"/>
		</xsl:if>

		<xsl:apply-templates select="content"/>

		<xsl:apply-templates select="footer"/>

	</body></html>
</xsl:template>

<xsl:template match="header">
	<div id="pageHeader">
		<xsl:copy-of select="channel[@name='Header']"/>
		<div id="schoolLogo"></div>
		<!-- <xsl:copy-of select="channel[@fname='session-locales-selector']"/> -->
		<!-- <xsl:copy-of select="channel[@name='Login']"/> -->
	</div>
</xsl:template>

<xsl:template match="navigation">
	<ul id="tabNavigation">
	<xsl:for-each select="tab">
		<xsl:choose>
		<xsl:when test="@activeTab='false'">
			<li>
			<xsl:attribute name="id">tab-<xsl:value-of select="position()"/></xsl:attribute>
				<a href="{$baseActionURL}?uP_root=root&amp;uP_sparam=activeTab&amp;activeTab={position()}" rev="inactiveTab">
					<xsl:attribute name="accesskey"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="tabindex"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="title"><xsl:value-of select="@name"/></xsl:attribute>
					<span>
					<xsl:attribute name="class">tab-<xsl:value-of select="translate(@name,$uppercase,$lowercase)"/></xsl:attribute>
					<xsl:value-of select="@name"/>
					</span>
				</a>
			</li>
		</xsl:when>
		<xsl:when test="@activeTab='true'">
			<li class="focusedTab">
			<xsl:attribute name="id">tab-<xsl:value-of select="position()"/></xsl:attribute>
				<a href="javascript:void(0)" rev="activeTab">
					<xsl:attribute name="accesskey"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="tabindex"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="title"><xsl:value-of select="@name"/></xsl:attribute>
					<span>
					<xsl:attribute name="class">tab-<xsl:value-of select="translate(@name,$uppercase,$lowercase)"/></xsl:attribute>
					<xsl:value-of select="@name"/>
					</span>
				</a>
			</li>
		</xsl:when>
		</xsl:choose>
	</xsl:for-each>
	</ul>
	<div id="tabFooter"></div>
</xsl:template>
  
<xsl:template match="content">
	<xsl:choose>
		<xsl:when test="not(//focused)">
			<xsl:call-template name="contentRow"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="focused"/>
		</xsl:otherwise>
	</xsl:choose>
	</xsl:template>

	<xsl:template name="contentRow">
	<xsl:param name="numberOfColumns" select="count(column)" />
	<xsl:variable name="percentsign">%</xsl:variable>
	<xsl:variable name="nopercentsign"></xsl:variable>

	<xsl:if test="$numberOfColumns &gt; 1">
		<xsl:choose>
		<xsl:when test="column[last()]/@width = '100%'">
			<xsl:for-each select="column">
				<div><xsl:attribute name="class">display-<xsl:value-of select="$numberOfColumns"/>-columns</xsl:attribute>
				<div class="display-padded-column">
					<xsl:apply-templates select="channel"/>
				</div></div>
			</xsl:for-each>
		</xsl:when>
		<xsl:otherwise>
			<xsl:for-each select="column">
				<div><xsl:attribute name="class">display-<xsl:value-of select="translate(@width,$percentsign,$nopercentsign)"/>-percent</xsl:attribute>
				<div class="display-padded-column">
					<xsl:apply-templates select="channel"/>
				</div></div>
			</xsl:for-each>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:if>

	<xsl:if test="$numberOfColumns=1">
		<xsl:for-each select="column">
			<div class="display-100-percent"><div class="display-padded-column">
				<xsl:apply-templates select="channel"/>
			</div></div>
		</xsl:for-each>
	</xsl:if>

</xsl:template>

<xsl:template match="channel">
	<xsl:param name="detachedContent"/>
	<xsl:if test="@minimized != 'true'">
	<div class="channel-window-outside">
		<xsl:attribute name="id">windowID<xsl:value-of select="@ID"/></xsl:attribute>
		<div class="channel-window-inside">
			<div class="channel-header"><div>
				<h1>
					<xsl:attribute name="id">titleID<xsl:value-of select="@ID"/></xsl:attribute>
					<xsl:attribute name="class">channel-<xsl:value-of select="translate(@title,$uppercase,$lowercase)"/></xsl:attribute>
					<xsl:value-of select="@title"/>
				</h1>
				<xsl:choose>
					<xsl:when test="$detachedContent='true'">
						<xsl:call-template name="detachedChannelControls"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="controls"/>
					</xsl:otherwise>
				</xsl:choose>
			</div></div>
		<div class="channel-content-border">
		<xsl:attribute name="id">channelID<xsl:value-of select="@ID"/></xsl:attribute>
			<div class="channel-content-body">
				<xsl:copy-of select="."/>
			</div>
		</div>
	</div></div>
	</xsl:if>

	<xsl:if test="@minimized = 'true'">
	<div class="channel-window-outside-minimized"><div class="channel-window-inside-minimized">
		<div class="channel-header-minimized"><div>
			<h1>
				<xsl:attribute name="class">channel-<xsl:value-of select="translate(@title,$uppercase,$lowercase)"/></xsl:attribute>
				<xsl:value-of select="@title"/>
			</h1>
			<xsl:choose>
				<xsl:when test="$detachedContent='true'">
					<xsl:call-template name="detachedChannelControls"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="controls"/>
				</xsl:otherwise>
			</xsl:choose>
		</div></div>
	</div></div>
	</xsl:if>

</xsl:template>

<xsl:template match="focused">
	<xsl:apply-templates select="channel" mode="focused"/>
</xsl:template>

<xsl:template match="channel" mode="focused">

	<div class="display-1-columns"><div class="display-padded-column">
		<div class="channel-window-outside"><div class="channel-window-inside">
			<div class="channel-header">
				<div>
					<h1>
						<xsl:attribute name="class">channel-<xsl:value-of select="translate(@title,$uppercase,$lowercase)"/></xsl:attribute>
						<xsl:value-of select="@title"/>
					</h1>
					<xsl:call-template name="controls"/>
				</div>
			</div>
			<div class="channel-content-border"><div class="channel-content-body">
				<xsl:copy-of select="."/>
			</div></div>
		</div></div>
	</div></div>

</xsl:template>

<xsl:template match="footer">

	<div class="display-100-percent"><div class="display-padded-column">
	<div class="channel-window-outside-minimized"><div class="channel-window-inside-minimized">
		<div class="channel-header-minimized"><div>
	  <xsl:for-each select="channel">
	      <xsl:copy-of select="."/>
	  </xsl:for-each>
		</div></div>
	</div></div>
	</div></div>
	
</xsl:template>

<xsl:template name="controls">

	<xsl:if test="//focused">
		<a href="{$baseActionURL}?uP_root=root" title="Return to uPortal" tabindex="-1">
			<img src="{$mediaPathControls}/return.gif" width="16" height="16" alt="Return to uPortal" border="0" />
		</a>
	</xsl:if>

	<xsl:if test="not(@hasHelp='false')">
		<a href="{$baseActionURL}?uP_help_target={@ID}" title="View help information for this channel" tabindex="-1">
			<img src="{$mediaPathControls}/help.gif" width="16" height="16" alt="View help information for this channel" border="0" />
		</a>
	</xsl:if>

	<xsl:if test="not(@hasAbout='false')">
		<a href="{$baseActionURL}?uP_about_target={@ID}" title="Information about this channel" tabindex="-1">
			<img src="{$mediaPathControls}/about.gif" width="16" height="16" alt="Information about this channel" border="0" />
		</a>
	</xsl:if>

	<xsl:if test="not(@editable='false')">
		<a href="{$baseActionURL}?uP_edit_target={@ID}" title="Edit the settings for this channel" tabindex="-1">
			<img src="{$mediaPathControls}/edit.gif" width="16" height="16" alt="Edit the settings for this channel" border="0" />
		</a>
	</xsl:if>

	<xsl:if test="@printable='true'">
		<a href="{$baseActionURL}?uP_print_target={@ID}" id="print{@ID}" rev="printChannel" rel="{@ID}" title="Print the content of this channel" tabindex="-1">
			<img src="{$mediaPathControls}/print.gif" width="16" height="16" alt="Print the content of this channel" border="0" />
		</a>
	</xsl:if>

	<xsl:if test="not(//focused)">
		<a href="{$baseActionURL}?uP_root={@ID}" id="focus{@ID}" rev="focusChannel" rel="{@ID}" title="View this channel separately" tabindex="-1">
			<img src="{$mediaPathControls}/focus.gif" width="16" height="16" alt="View this channel separately" border="0" />
		</a>
	</xsl:if>

	<xsl:if test="not(//focused)">
		<xsl:choose>
		<xsl:when test="@minimized='true'">
			<a href="{$baseActionURL}?uP_tcattr=minimized&amp;minimized_channelId={@ID}&amp;minimized_{@ID}_value=false" title="View the content of this channel" tabindex="-1">
				<img src="{$mediaPathControls}/maximize.gif" width="16" height="16" alt="View the content of this channel" border="0" />
			</a>
		</xsl:when>
		<xsl:otherwise>
			<a href="{$baseActionURL}?uP_tcattr=minimized&amp;minimized_channelId={@ID}&amp;minimized_{@ID}_value=true" id="minmax{@ID}" rev="minmaxChannel" rel="{@ID}" title="Hide the content of this channel" tabindex="-1">
				<img src="{$mediaPathControls}/minimize.gif" width="16" height="16" alt="Hide the content of this channel" border="0"  />
			</a>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:if>

	<a href="{$baseActionURL}?uP_detach_target={@ID}" id="detach{@ID}" rev="detachChannel" rel="{@ID}" title="View this channel in a new window (link opens in a new window)" tabindex="-1">
		<img src="{$mediaPathControls}/detach.gif" width="16" height="16" alt="View this channel in a new window" border="0" />
	</a>

	<xsl:if test="not(@unremovable='true') and not(//focused) and /layout/navigation/tab[@activeTab='true']/@immutable='false'">
		<a href="{$baseActionURL}?uP_remove_target={@ID}" rev="removeChannel" title="Remove this channel" tabindex="-1">
			<img src="{$mediaPath}/{$skin}/controls/remove.gif" alt="Remove this channel" width="16" height="16" border="0"/>
		</a>
	</xsl:if>

</xsl:template>

<xsl:template name="detachedChannelControls">

	<xsl:if test="not(@hasHelp='false')">
		<a href="{$baseActionURL}?uP_help_target={@ID}" title="View help information for this channel" tabindex="-1">
			<img src="{$mediaPathControls}/help.gif" width="16" height="16" alt="View help information for this channel" border="0" />
		</a>
	</xsl:if>

	<xsl:if test="not(@hasAbout='false')">
		<a href="{$baseActionURL}?uP_about_target={@ID}" title="Information about this channel" tabindex="-1">
			<img src="{$mediaPathControls}/about.gif" width="16" height="16" alt="Information about this channel" border="0" />
		</a>
	</xsl:if>
	<xsl:if test="not(@editable='false')">

		<a href="{$baseActionURL}?uP_edit_target={@ID}" title="Edit the settings for this channel" tabindex="-1">
			<img src="{$mediaPathControls}/edit.gif" width="16" height="16" alt="Edit the settings for this channel" border="0" />
		</a>
	</xsl:if>

	<xsl:if test="@printable='true'">
		<a href="{$baseActionURL}?uP_print_target={@ID}" id="print{@ID}" rev="printChannel" rel="{@ID}" title="Print the content of this channel" tabindex="-1">
			<img src="{$mediaPathControls}/print.gif" width="16" height="16" alt="Print the content of this channel" border="0" />
		</a>
	</xsl:if>

	<a href="{$baseActionURL}?uP_root=root" rev="closeWindow" title="Close this Window" tabindex="-1">
		<img src="{$mediaPathControls}/close.gif" alt="Close this Window" width="16" height="16" border="0" />
	</a>

</xsl:template>
 
</xsl:stylesheet>
